Directive

Enum Directive 

pub enum Directive {
Show 38 variants Byte, CSeg, CSegSize, Db, Def, Device, DSeg, Dw, EndM, EndMacro, Equ, ESeg, Exit, Include, IncludePath, List, ListMac, Macro, NoList, Org, Set, Define, Else, ElIf, Endif, Error, If, IfDef, IfNDef, Message, Dd, Dq, Undef, Warning, Overlap, NoOverlap, Pragma, Custom(String),
}

Variants



Byte

Reserve bytes for a variable in RAM



CSeg

Code segment



CSegSize

Program memory size for AT94K (unsupported)



Db

Define constant bytes in program memory and EEPROM



Def

Define a symbolic name on a register



Device

Device specific



DSeg

Data segment



Dw

Define constant words in program memory and EEPROM



EndM

End of macro define



EndMacro



Equ

Set a symbol equal to an expression



ESeg

EEPROM segment



Exit

Exit from file



Include

Read source from another file



IncludePath

Another path for includes



List

Turn listfile generation on (unsupported)



ListMac

Turn macro expansion in list file on (unsupported)



Macro

Begin macro



NoList

Turn listfile generation off (unsupported)



Org

Set program origin



Set

Set a symbol to an expression



Define

Define a preprocessor macro



Else

Conditional assembly - alternate branches



ElIf



Endif

Conditional assembly - end conditional block



Error

Outputs an error message



If

Conditional assembly - begin of conditional block



IfDef



IfNDef



Message

Outputs a message string



Dd

Define constant double words in program memory and EEPROM



Dq

Define constant quad words in program memory and EEPROM



Undef

Undefine register symbol



Warning

Outputs a warning message



Overlap

Set up/down overlapping section (unsupported)



NoOverlap



Pragma

Preprocessor pragmas



Custom(String)

For extend and macross support

Implementations

Source

impl Directive

pub fn parse( &self, opts: &DirectiveOps, context: &ParseContext, point: CodePoint, ) -> Result<NextItem, Error>